@@ -337,7 +337,7 @@ impl WriteableGraphStorage for AdjacencyListStorage {
         if !self.edges.is_empty() {
             for outgoing in self.edges.values() {
                 for target in outgoing {
-                    roots.remove(&target);
+                    roots.remove(target);
                 }
             }
         }
@@ -379,7 +379,7 @@ impl WriteableGraphStorage for AdjacencyListStorage {
         } else {
             for root_node in &roots {
                 let mut dfs = CycleSafeDFS::new(self, *root_node, 0, usize::max_value());
-                while let Some(step) = dfs.next() {
+                for step in &mut dfs {
                     number_of_visits += 1;
                     stats.max_depth = std::cmp::max(stats.max_depth, step.distance);
                 }
